pub struct StatusCommand {
pub format: Option<String>,
pub fallback: Option<String>,
}Fields
format: Option<String>A format string describing the output of the command.
fallback: Option<String>The message that gets printed to the console if no time is currently tracked.